#!/bin/bash

#===============================================================================
#  DEBUG OPTIONS
#===============================================================================
# set -o xtrace -o verbose
# exec &> >(tee /tmp/${0##*/}_$(date '+%Y%m%d%H%M%S').log)

#===============================================================================
#   ARGUMENTS
#===============================================================================
# Executes this command after master failover
# Special values:
#   %d = node id
#   %h = host name
#   %p = port number
#   %D = database cluster path
#   %m = new master node id
#   %H = hostname of the new master node
#   %M = old master node id
#   %P = old primary node id
#   %r = new master port number
#   %R = new master database cluster path
#   %% = '%' character
#
#   master node id = 稼働中ノードのうち最もノード番号が若いノード

FAILED_NODE_ID="$1"
FAILED_HOST="$2"
NEW_MASTER_NODE_HOST="$3"
OLD_PRIMARY_NODE_ID="$4"

#===============================================================================
#   MAIN SCRIPT
#===============================================================================
# このスクリプトの実行対象がスタンバイノードの場合はレプリケーションスロットを削除する
if [ $FAILED_NODE_ID -ne $OLD_PRIMARY_NODE_ID ]; then
	old_primary_node_host=$(pcp_node_info -w $OLD_PRIMARY_NODE_ID | awk '{print $1}')
	old_primary_node_port=$(pcp_node_info -w $OLD_PRIMARY_NODE_ID | awk '{print $2}')
	ssh -T -o StrictHostKeyChecking=no -o UserKnownHostsFile=/dev/null \
	postgres@$old_primary_node_host "source .bash_profile && psql -c \"SELECT pg_drop_replication_slot('$FAILED_HOST');\""
	exit
fi

# 稼働中で一番ノード ID が若いスタンバイノードをプライマリに昇格する
ssh -T -o StrictHostKeyChecking=no -o UserKnownHostsFile=/dev/null \
	postgres@$NEW_MASTER_NODE_HOST 'source .bash_profile && pg_ctl promote'
